@@ -72,9 +72,12 @@ func (d *detector) IssueFeatures() (IssueFeatures, error) {
 }
 
 func (d *detector) PullRequestFeatures() (PullRequestFeatures, error) {
-	if !ghinstance.IsEnterprise(d.host) {
-		return allPullRequestFeatures, nil
-	}
+	// TODO: reinstate the short-circuit once the APIs are fully available on github.com
+	// https://github.com/cli/cli/issues/5778
+	//
+	// if !ghinstance.IsEnterprise(d.host) {
+	// 	return allPullRequestFeatures, nil
+	// }
 
 	features := PullRequestFeatures{
 		ReviewDecision:       true,
