@@ -20,6 +20,14 @@ func TestPullRequestFeatures(t *testing.T) {
 		{
 			name:     "github.com",
 			hostname: "github.com",
+			queryResponse: map[string]string{
+				`query PullRequest_fields\b`: heredoc.Doc(`
+					{ "data": { "PullRequest": { "fields": [
+						{"name": "isInMergeQueue"},
+						{"name": "isMergeQueueEnabled"}
+					] } } }
+				`),
+			},
 			wantFeatures: PullRequestFeatures{
 				ReviewDecision:       true,
 				StatusCheckRollup:    true,
@@ -28,6 +36,23 @@ func TestPullRequestFeatures(t *testing.T) {
 			},
 			wantErr: false,
 		},
+		{
+			name:     "github.com with no merge queue",
+			hostname: "github.com",
+			queryResponse: map[string]string{
+				`query PullRequest_fields\b`: heredoc.Doc(`
+					{ "data": { "PullRequest": { "fields": [
+					] } } }
+				`),
+			},
+			wantFeatures: PullRequestFeatures{
+				ReviewDecision:       true,
+				StatusCheckRollup:    true,
+				BranchProtectionRule: true,
+				MergeQueue:           false,
+			},
+			wantErr: false,
+		},
 		{
 			name:     "GHE",
 			hostname: "git.my.org",
