@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -368,7 +368,7 @@ func Test_apiRun(t *testing.T) {
 			name: "success",
 			httpResponse: &http.Response{
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`bam!`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`bam!`)),
 			},
 			err:    nil,
 			stdout: `bam!`,
@@ -383,7 +383,7 @@ func Test_apiRun(t *testing.T) {
 				Proto:      "HTTP/1.1",
 				Status:     "200 Okey-dokey",
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`body`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`body`)),
 				Header:     http.Header{"Content-Type": []string{"text/plain"}},
 			},
 			err:    nil,
@@ -404,7 +404,7 @@ func Test_apiRun(t *testing.T) {
 			name: "REST error",
 			httpResponse: &http.Response{
 				StatusCode: 400,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json; charset=utf-8"}},
 			},
 			err:    cmdutil.SilentError,
@@ -415,7 +415,7 @@ func Test_apiRun(t *testing.T) {
 			name: "REST string errors",
 			httpResponse: &http.Response{
 				StatusCode: 400,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"errors": ["ALSO", "FINE"]}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"errors": ["ALSO", "FINE"]}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json; charset=utf-8"}},
 			},
 			err:    cmdutil.SilentError,
@@ -429,7 +429,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"errors": [{"message":"AGAIN"}, {"message":"FINE"}]}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"errors": [{"message":"AGAIN"}, {"message":"FINE"}]}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json; charset=utf-8"}},
 			},
 			err:    cmdutil.SilentError,
@@ -440,7 +440,7 @@ func Test_apiRun(t *testing.T) {
 			name: "failure",
 			httpResponse: &http.Response{
 				StatusCode: 502,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`gateway timeout`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`gateway timeout`)),
 			},
 			err:    cmdutil.SilentError,
 			stdout: `gateway timeout`,
@@ -453,7 +453,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`body`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`body`)),
 			},
 			err:    nil,
 			stdout: ``,
@@ -469,7 +469,7 @@ func Test_apiRun(t *testing.T) {
 				Proto:      "HTTP/1.1",
 				Status:     "200 Okey-dokey",
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`body`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`body`)),
 				Header:     http.Header{"Content-Type": []string{"text/plain"}},
 			},
 			err:    nil,
@@ -483,7 +483,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"status":"not a cat"}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"status":"not a cat"}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json"}},
 			},
 			err:    nil,
@@ -497,7 +497,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 400,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json; charset=utf-8"}},
 			},
 			err:    cmdutil.SilentError,
@@ -511,7 +511,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 200,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`[{"name":"Mona"},{"name":"Hubot"}]`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`[{"name":"Mona"},{"name":"Hubot"}]`)),
 				Header:     http.Header{"Content-Type": []string{"application/json"}},
 			},
 			err:    nil,
@@ -525,7 +525,7 @@ func Test_apiRun(t *testing.T) {
 			},
 			httpResponse: &http.Response{
 				StatusCode: 400,
-				Body:       ioutil.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
+				Body:       io.NopCloser(bytes.NewBufferString(`{"message": "THIS IS FINE"}`)),
 				Header:     http.Header{"Content-Type": []string{"application/json; charset=utf-8"}},
 			},
 			err:    cmdutil.SilentError,
@@ -536,9 +536,9 @@ func Test_apiRun(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			io, _, stdout, stderr := iostreams.Test()
+			ios, _, stdout, stderr := iostreams.Test()
 
-			tt.options.IO = io
+			tt.options.IO = ios
 			tt.options.Config = func() (config.Config, error) { return config.NewBlankConfig(), nil }
 			tt.options.HttpClient = func() (*http.Client, error) {
 				var tr roundTripper = func(req *http.Request) (*http.Response, error) {
@@ -565,33 +565,33 @@ func Test_apiRun(t *testing.T) {
 }
 
 func Test_apiRun_paginationREST(t *testing.T) {
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 
 	requestCount := 0
 	responses := []*http.Response{
 		{
 			StatusCode: 200,
-			Body:       ioutil.NopCloser(bytes.NewBufferString(`{"page":1}`)),
+			Body:       io.NopCloser(bytes.NewBufferString(`{"page":1}`)),
 			Header: http.Header{
 				"Link": []string{`<https://api.github.com/repositories/1227/issues?page=2>; rel="next", <https://api.github.com/repositories/1227/issues?page=3>; rel="last"`},
 			},
 		},
 		{
 			StatusCode: 200,
-			Body:       ioutil.NopCloser(bytes.NewBufferString(`{"page":2}`)),
+			Body:       io.NopCloser(bytes.NewBufferString(`{"page":2}`)),
 			Header: http.Header{
 				"Link": []string{`<https://api.github.com/repositories/1227/issues?page=3>; rel="next", <https://api.github.com/repositories/1227/issues?page=3>; rel="last"`},
 			},
 		},
 		{
 			StatusCode: 200,
-			Body:       ioutil.NopCloser(bytes.NewBufferString(`{"page":3}`)),
+			Body:       io.NopCloser(bytes.NewBufferString(`{"page":3}`)),
 			Header:     http.Header{},
 		},
 	}
 
 	options := ApiOptions{
-		IO: io,
+		IO: ios,
 		HttpClient: func() (*http.Client, error) {
 			var tr roundTripper = func(req *http.Request) (*http.Response, error) {
 				resp := responses[requestCount]
@@ -624,14 +624,14 @@ func Test_apiRun_paginationREST(t *testing.T) {
 }
 
 func Test_apiRun_paginationGraphQL(t *testing.T) {
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 
 	requestCount := 0
 	responses := []*http.Response{
 		{
 			StatusCode: 200,
 			Header:     http.Header{"Content-Type": []string{`application/json`}},
-			Body: ioutil.NopCloser(bytes.NewBufferString(`{
+			Body: io.NopCloser(bytes.NewBufferString(`{
 				"data": {
 					"nodes": ["page one"],
 					"pageInfo": {
@@ -644,7 +644,7 @@ func Test_apiRun_paginationGraphQL(t *testing.T) {
 		{
 			StatusCode: 200,
 			Header:     http.Header{"Content-Type": []string{`application/json`}},
-			Body: ioutil.NopCloser(bytes.NewBufferString(`{
+			Body: io.NopCloser(bytes.NewBufferString(`{
 				"data": {
 					"nodes": ["page two"],
 					"pageInfo": {
@@ -657,7 +657,7 @@ func Test_apiRun_paginationGraphQL(t *testing.T) {
 	}
 
 	options := ApiOptions{
-		IO: io,
+		IO: ios,
 		HttpClient: func() (*http.Client, error) {
 			var tr roundTripper = func(req *http.Request) (*http.Response, error) {
 				resp := responses[requestCount]
@@ -687,14 +687,14 @@ func Test_apiRun_paginationGraphQL(t *testing.T) {
 		Variables map[string]interface{}
 	}
 
-	bb, err := ioutil.ReadAll(responses[0].Request.Body)
+	bb, err := io.ReadAll(responses[0].Request.Body)
 	require.NoError(t, err)
 	err = json.Unmarshal(bb, &requestData)
 	require.NoError(t, err)
 	_, hasCursor := requestData.Variables["endCursor"].(string)
 	assert.Equal(t, false, hasCursor)
 
-	bb, err = ioutil.ReadAll(responses[1].Request.Body)
+	bb, err = io.ReadAll(responses[1].Request.Body)
 	require.NoError(t, err)
 	err = json.Unmarshal(bb, &requestData)
 	require.NoError(t, err)
@@ -704,15 +704,15 @@ func Test_apiRun_paginationGraphQL(t *testing.T) {
 }
 
 func Test_apiRun_paginated_template(t *testing.T) {
-	io, _, stdout, stderr := iostreams.Test()
-	io.SetStdoutTTY(true)
+	ios, _, stdout, stderr := iostreams.Test()
+	ios.SetStdoutTTY(true)
 
 	requestCount := 0
 	responses := []*http.Response{
 		{
 			StatusCode: 200,
 			Header:     http.Header{"Content-Type": []string{`application/json`}},
-			Body: ioutil.NopCloser(bytes.NewBufferString(`{
+			Body: io.NopCloser(bytes.NewBufferString(`{
 				"data": {
 					"nodes": [
 						{
@@ -730,7 +730,7 @@ func Test_apiRun_paginated_template(t *testing.T) {
 		{
 			StatusCode: 200,
 			Header:     http.Header{"Content-Type": []string{`application/json`}},
-			Body: ioutil.NopCloser(bytes.NewBufferString(`{
+			Body: io.NopCloser(bytes.NewBufferString(`{
 				"data": {
 					"nodes": [
 						{
@@ -748,7 +748,7 @@ func Test_apiRun_paginated_template(t *testing.T) {
 	}
 
 	options := ApiOptions{
-		IO: io,
+		IO: ios,
 		HttpClient: func() (*http.Client, error) {
 			var tr roundTripper = func(req *http.Request) (*http.Response, error) {
 				resp := responses[requestCount]
@@ -782,14 +782,14 @@ func Test_apiRun_paginated_template(t *testing.T) {
 		Variables map[string]interface{}
 	}
 
-	bb, err := ioutil.ReadAll(responses[0].Request.Body)
+	bb, err := io.ReadAll(responses[0].Request.Body)
 	require.NoError(t, err)
 	err = json.Unmarshal(bb, &requestData)
 	require.NoError(t, err)
 	_, hasCursor := requestData.Variables["endCursor"].(string)
 	assert.Equal(t, false, hasCursor)
 
-	bb, err = ioutil.ReadAll(responses[1].Request.Body)
+	bb, err = io.ReadAll(responses[1].Request.Body)
 	require.NoError(t, err)
 	err = json.Unmarshal(bb, &requestData)
 	require.NoError(t, err)
@@ -825,14 +825,14 @@ func Test_apiRun_inputFile(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			io, stdin, _, _ := iostreams.Test()
+			ios, stdin, _, _ := iostreams.Test()
 			resp := &http.Response{StatusCode: 204}
 
 			inputFile := tt.inputFile
 			if tt.inputFile == "-" {
 				_, _ = stdin.Write(tt.inputContents)
 			} else {
-				f, err := ioutil.TempFile(tempDir, tt.inputFile)
+				f, err := os.CreateTemp(tempDir, tt.inputFile)
 				if err != nil {
 					t.Fatal(err)
 				}
@@ -847,11 +847,11 @@ func Test_apiRun_inputFile(t *testing.T) {
 				RequestInputFile: inputFile,
 				RawFields:        []string{"a=b", "c=d"},
 
-				IO: io,
+				IO: ios,
 				HttpClient: func() (*http.Client, error) {
 					var tr roundTripper = func(req *http.Request) (*http.Response, error) {
 						var err error
-						if bodyBytes, err = ioutil.ReadAll(req.Body); err != nil {
+						if bodyBytes, err = io.ReadAll(req.Body); err != nil {
 							return nil, err
 						}
 						resp.Request = req
@@ -879,11 +879,11 @@ func Test_apiRun_inputFile(t *testing.T) {
 }
 
 func Test_apiRun_cache(t *testing.T) {
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 
 	requestCount := 0
 	options := ApiOptions{
-		IO: io,
+		IO: ios,
 		HttpClient: func() (*http.Client, error) {
 			var tr roundTripper = func(req *http.Request) (*http.Response, error) {
 				requestCount++
@@ -918,11 +918,11 @@ func Test_apiRun_cache(t *testing.T) {
 }
 
 func Test_parseFields(t *testing.T) {
-	io, stdin, _, _ := iostreams.Test()
+	ios, stdin, _, _ := iostreams.Test()
 	fmt.Fprint(stdin, "pasted contents")
 
 	opts := ApiOptions{
-		IO: io,
+		IO: ios,
 		RawFields: []string{
 			"robot=Hubot",
 			"destroyer=false",
@@ -954,7 +954,7 @@ func Test_parseFields(t *testing.T) {
 }
 
 func Test_magicFieldValue(t *testing.T) {
-	f, err := ioutil.TempFile(t.TempDir(), "gh-test")
+	f, err := os.CreateTemp(t.TempDir(), "gh-test")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -962,7 +962,7 @@ func Test_magicFieldValue(t *testing.T) {
 
 	fmt.Fprint(f, "file contents")
 
-	io, _, _, _ := iostreams.Test()
+	ios, _, _, _ := iostreams.Test()
 
 	type args struct {
 		v    string
@@ -1003,7 +1003,7 @@ func Test_magicFieldValue(t *testing.T) {
 			args: args{
 				v: ":owner",
 				opts: &ApiOptions{
-					IO: io,
+					IO: ios,
 					BaseRepo: func() (ghrepo.Interface, error) {
 						return ghrepo.New("hubot", "robot-uprising"), nil
 					},
@@ -1017,7 +1017,7 @@ func Test_magicFieldValue(t *testing.T) {
 			args: args{
 				v: "{owner}",
 				opts: &ApiOptions{
-					IO: io,
+					IO: ios,
 					BaseRepo: func() (ghrepo.Interface, error) {
 						return ghrepo.New("hubot", "robot-uprising"), nil
 					},
@@ -1030,7 +1030,7 @@ func Test_magicFieldValue(t *testing.T) {
 			name: "file",
 			args: args{
 				v:    "@" + f.Name(),
-				opts: &ApiOptions{IO: io},
+				opts: &ApiOptions{IO: ios},
 			},
 			want:    []byte("file contents"),
 			wantErr: false,
@@ -1039,7 +1039,7 @@ func Test_magicFieldValue(t *testing.T) {
 			name: "file error",
 			args: args{
 				v:    "@",
-				opts: &ApiOptions{IO: io},
+				opts: &ApiOptions{IO: ios},
 			},
 			want:    nil,
 			wantErr: true,
@@ -1061,7 +1061,7 @@ func Test_magicFieldValue(t *testing.T) {
 }
 
 func Test_openUserFile(t *testing.T) {
-	f, err := ioutil.TempFile(t.TempDir(), "gh-test")
+	f, err := os.CreateTemp(t.TempDir(), "gh-test")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1075,7 +1075,7 @@ func Test_openUserFile(t *testing.T) {
 	}
 	defer file.Close()
 
-	fb, err := ioutil.ReadAll(file)
+	fb, err := io.ReadAll(file)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1272,14 +1272,14 @@ func Test_previewNamesToMIMETypes(t *testing.T) {
 }
 
 func Test_processResponse_template(t *testing.T) {
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 
 	resp := http.Response{
 		StatusCode: 200,
 		Header: map[string][]string{
 			"Content-Type": {"application/json"},
 		},
-		Body: ioutil.NopCloser(strings.NewReader(`[
+		Body: io.NopCloser(strings.NewReader(`[
 			{
 				"title": "First title",
 				"labels": [{"name":"bug"}, {"name":"help wanted"}]
@@ -1295,11 +1295,11 @@ func Test_processResponse_template(t *testing.T) {
 	}
 
 	opts := ApiOptions{
-		IO:       io,
+		IO:       ios,
 		Template: `{{range .}}{{.title}} ({{.labels | pluck "name" | join ", " }}){{"\n"}}{{end}}`,
 	}
-	template := export.NewTemplate(io, opts.Template)
-	_, err := processResponse(&resp, &opts, ioutil.Discard, &template)
+	template := export.NewTemplate(ios, opts.Template)
+	_, err := processResponse(&resp, &opts, io.Discard, &template)
 	require.NoError(t, err)
 
 	err = template.End()
@@ -1385,7 +1385,7 @@ func Test_parseErrorResponse(t *testing.T) {
 			if (err != nil) != tt.wantErr {
 				t.Errorf("parseErrorResponse() error = %v, wantErr %v", err, tt.wantErr)
 			}
-			if gotString, _ := ioutil.ReadAll(got); tt.args.input != string(gotString) {
+			if gotString, _ := io.ReadAll(got); tt.args.input != string(gotString) {
 				t.Errorf("parseErrorResponse() got = %q, want %q", string(gotString), tt.args.input)
 			}
 			if got1 != tt.wantErrMsg {
